pub struct MultipartField {
pub name: String,
pub filename: Option<String>,
pub content_type: Option<String>,
pub bytes: Bytes,
}Expand description
A buffered multipart form field. Carries name, filename, content type, and bytes across the provider trait boundary without depending on any HTTP client crate.
Fields
name: Stringfilename: Option<String>content_type: Option<String>bytes: BytesTrait Implementations
Sourceimpl Clone for MultipartField
impl Clone for MultipartField
Sourcefn clone(&self) -> MultipartField
fn clone(&self) -> MultipartField
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl !Freeze for MultipartField
impl RefUnwindSafe for MultipartField
impl Send for MultipartField
impl Sync for MultipartField
impl Unpin for MultipartField
impl UnsafeUnpin for MultipartField
impl UnwindSafe for MultipartField